@@ -17,5 +17,13 @@
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
+'''
+Contains a function to return the current version number of ibus-table.
+'''
 def get_version():
-    return "1.9.20"
+    '''
+    Returns the current version number of ibus-table.
+
+    :rtype: String
+    '''
+    return '1.9.21'
